
clear;

%%%%%%%%%%%%%%%%%%%% simulando la ecuacin %%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%% y(t)=alfa+beta*(x(t)^gamma)+u(t)%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T = 200;                                  % nmero de datos
xm = 6;                                   % valor medio de X
sigmapi = 1;                              % desviacin tpica de X alrededor de la media
x = xm+normrnd(0,sigmapi,T,1);            % generacin de la variable x
shock = normrnd(0,1,T+1000,1);           % generacin de una normal(0,1)
shock = shock(1001:1000+T,1);             % perturbacin aleatoria (u_t)
sigma = 10.0; 
alfat = 10.0;                             % parmetro alfa terico
betat = 0.8;                              % parmetro beta terico
gammat = 2.5;
y = alfat+betat*(x.^gammat)+sigma.*shock; % generacin de la variable Y

global vari                               % declaramos los datos simulados como variables globales
vari = [y x];
plot(y,x,'b.')
pause

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%  Estimacin mediante rejilla de valores de gamma utilizando el sistema de condiciones 
%  de primer orden (ver apuntes de clase). No se estima ningua regresin.
 obj = [];
 for gamma = 0.5:0.01:5.0
 xgamma = x.^gamma;
 xgamma2 = xgamma.^2;
 beta2 = (mean(y.*xgamma)-mean(y)*mean(xgamma))/(mean(xgamma2)-mean(xgamma)^2);
 beta1 = mean(y)-beta2*mean(xgamma);
 resid = y-beta1-beta2.*xgamma;
 scr = resid'*resid;
 obj = [obj; beta1 beta2 gamma scr];
 end
[a,b] = find(obj(:,4)==min(obj(:,4)));
display('Estimacion utilizando unicamente CPO')
display('constante     pendiente    gamma   SCR')
obj(a,1:3)
obj(a,4)
 

%  Estimacin mediante rejilla de valores de gamma
R = [];
for gamma = 0.1:0.1:5.0
x_g = x.^gamma;
[bhat,residuos,sigma2,vcov,estadt,pvalort,R2]=mco_breve(y,[ones(size(y,1),1) x_g]);
SCR = residuos'*residuos;
R = [R;  bhat' gamma SCR];
end
figure
plot(R(:,4))
[a,b]=find(R(:,4)==min(R(:,4)));
display('Estimacion mediante rejilla de valores de Gamma')
display(' constante     pendiente    gamma  SCR')
R(a,1:3)
R(a,4)

% Contrastando H=0: gamma=1.0
[bhat,residuos,sigma2,vcov,estadt,pvalort,R2]=mco_breve(y,[ones(size(y,1),1) x]);
SCR1 = residuos'*residuos;
display('F-test para el contraste de H0: gamma=1')
SCSR = R(a,4);
F = (T-2)*(SCR1-SCSR)/SCSR

%  Estimacion mediante algoritmo de optimizacin
[bhat,residuos,sigma2,vcov,estadt,pvalort,R2]=mco_breve(y,[ones(size(y,1),1) x]);
theta0 = R(a,1:3);
options=optimset('Display','Iter','MaxFunEvals',100,'MaxIter',100,'TolFun',0.00001);
[theta1,fval,exitflag] = fminsearch('potsr',theta0);
xgamma = x.^theta1(1,3);
res_opt = y-theta1(1,1)-theta1(1,2).*xgamma;
SCR = res_opt'*res_opt;
display('Estimacion mediante algoritmo numrico')
display(' constante     pendiente    gamma  SCR')
theta1
SCR






















